@@ -1,6 +1,5 @@
-from faker.generator import Generator  # noqa F401
 from faker.factory import Factory  # noqa F401
+from faker.generator import Generator  # noqa F401
+from faker.proxy import Faker  # noqa F401
 
-VERSION = '1.0.7'
-
-Faker = Factory.create
+VERSION = '4.0.3'
