@@ -1,18 +1,12 @@
-# coding=utf-8
-
-from __future__ import unicode_literals
-from __future__ import absolute_import
-
-from importlib import import_module
 import locale as pylocale
-
 import logging
 import sys
 
-from faker import Generator
-from faker.config import DEFAULT_LOCALE, PROVIDERS, AVAILABLE_LOCALES
-from faker.utils.loading import list_module
+from importlib import import_module
 
+from faker.config import AVAILABLE_LOCALES, DEFAULT_LOCALE, PROVIDERS
+from faker.generator import Generator
+from faker.utils.loading import list_module
 
 logger = logging.getLogger(__name__)
 
@@ -24,7 +18,7 @@ else:
     logger.debug('Not in REPL -> leaving logger event level as is.')
 
 
-class Factory(object):
+class Factory:
 
     @classmethod
     def create(
@@ -41,7 +35,7 @@ class Factory(object):
         locale = locale.replace('-', '_') if locale else DEFAULT_LOCALE
         locale = pylocale.normalize(locale).split('.')[0]
         if locale not in AVAILABLE_LOCALES:
-            msg = 'Invalid configuration for faker locale `{0}`'.format(locale)
+            msg = 'Invalid configuration for faker locale `{}`'.format(locale)
             raise AttributeError(msg)
 
         config['locale'] = locale
@@ -82,7 +76,7 @@ class Factory(object):
         if provider_class:
             return provider_class, None
 
-        msg = 'Unable to find provider `{0}` with locale `{1}`'.format(
+        msg = 'Unable to find provider `{}` with locale `{}`'.format(
             provider, locale)
         raise ValueError(msg)
 
@@ -102,11 +96,10 @@ class Factory(object):
                 locale = getattr(
                     provider_module, 'default_locale', DEFAULT_LOCALE)
                 logger.debug('Specified locale `{}` is not available for '
-                               'provider `{}`. Locale reset to `{}` for this '
-                               'provider.'.format(unavailable_locale,
-                                                  provider_module.__name__,
-                                                  locale)
-                               )
+                             'provider `{}`. Locale reset to `{}` for this '
+                             'provider.'.format(
+                                 unavailable_locale, provider_module.__name__, locale),
+                             )
             else:
                 logger.debug('Provider `{}` has been localized to `{}`.'.format(
                     provider_module.__name__, locale))
@@ -120,10 +113,10 @@ class Factory(object):
         else:
 
             logger.debug('Provider `{}` does not feature localization. '
-                        'Specified locale `{}` is not utilized for this '
-                        'provider.'.format(
-                            provider_module.__name__, locale)
-                        )
+                         'Specified locale `{}` is not utilized for this '
+                         'provider.'.format(
+                             provider_module.__name__, locale),
+                         )
 
             if locale is not None:
                 provider_module = import_module(provider_path)
