@@ -1,5 +1,3 @@
-# coding=utf-8
-from __future__ import unicode_literals
 from .. import Provider as AddressProvider
 
 
@@ -9,13 +7,13 @@ class Provider(AddressProvider):
 
     street_name_formats = (
         '{{first_name}} {{last_name}}',
-        '{{last_name}}'
+        '{{last_name}}',
     )
 
     street_address_formats = ('{{building_number}} {{street_name}}', )
 
     address_formats = ('{{street_address}}\n{{city}} {{postcode}}',
-                       '{{street_address}}\n{{city}}-{{postcode}}',)
+                       '{{street_address}}\n{{city}}-{{postcode}}')
 
     building_number_formats = (
         '####', '###', '##', '#', '#/#', '##/##', '##/###', '##/####')
@@ -36,7 +34,7 @@ class Provider(AddressProvider):
         'अन्तर्गत',
         'अलांग',
         'अलीगढ',
-        'दादरा और नागर हवेली',
+        'दादरा और नगर हवेली',
         'अमरावती',
         'अमरोहा',
         'अनन्तपुर',
@@ -44,9 +42,6 @@ class Provider(AddressProvider):
         'जिससेबेलारी',
         'अनंतनाग',
         'भागलपुर',
-        'पेपरबोर्डस',
-        'त्रिबेनी',
-        'टिसूज',
         'भद्रक',
         'बचेली',
         'बहादुरगंज',
@@ -60,22 +55,14 @@ class Provider(AddressProvider):
         'दालखोला',
         'देवास',
         'चंडीगढ',
-        'फादर',
-        'चिन्नफ',
         'चिपलुन',
         'चक्रधरपुर',
         'चंबा',
         'फतहपुर',
         'फतेहपुर',
         'फतेहगढ',
-        'फतहपुर',
-        'फतहपुर',
-        'चित्तूर',
-        'चित्रकूट',
         'सभापतिने',
         'देवगढ़',
-        'द्वारारस्वीकृति',
-        'दालखोला',
         'धर्मापुरी',
         'पाकाला',
         'धारवाड',
@@ -88,6 +75,9 @@ class Provider(AddressProvider):
         'जिलोंपर',
         'विस्तारण',
         'मोतिहारी',
+        'लखनऊ',
+        'मुंबई',
+        'हैदराबाद',
     )
 
     states = (
@@ -102,13 +92,13 @@ class Provider(AddressProvider):
         'गोवा',
         'मध्य प्रदेश',
         'महाराष्ट्र',
-        'कश्मीर',
+        'जम्मू और कश्मीर',
         'केरल',
         'कर्नाटक',
         'मणिपुर',
         'मिजोरम',
         'मेघालय',
-        'सिबक्कम',
+        'सिक्किम',
         'राजस्थान',
         'पंजाब',
         'उडीसा',
@@ -118,24 +108,24 @@ class Provider(AddressProvider):
         'त्रिपुरा',
         'पश्चिमी बंगाल',
         'अंडमान और निकोबार',
-        'द्वीप समूह',
         'दमन और दीव',
-        'दादरा और नागर हवेली',
+        'दादरा और नगर हवेली',
         'दिल्ली',
         'पांडिचेरी',
-        'लक्षद्वीप')
+        'लक्षद्वीप',
+    )
 
     countries = (
-        'आर्मेनिया',
+        'आर्मीनिया',
         'यू.के.',
         'फ्रांस',
-        'अजेपटीना',
-        'ब्राजील',
+        'फलस्तीन',
+        'मिस्र',
+        'ब्राज़ील',
         'ईरान',
         'यूनान',
         'स्पेन',
-        'हमारे',
-        'जॉजिऩया',
+        'जॉर्जिया',
         'लेबनान',
         'सायप्रस',
         'सीरिया',
@@ -143,12 +133,9 @@ class Provider(AddressProvider):
         'रूस',
         'संयुक्त राज्य अमरीका',
         'नेदर्लान्ड',
-        'फ्रांस',
         'ऑस्ट्रेलिया',
         'एंटीगुआ',
         'बार्बुडा',
-        'अर्जेंटीना',
-        'आर्मेनिया',
         'ऑस्ट्रिया',
         'अज़रबाइजान',
         'बारबाडोस',
@@ -164,11 +151,9 @@ class Provider(AddressProvider):
         'बोस्निया',
         'हर्जेगोविना',
         'बोत्सवाना',
-        'ब्राजील',
         'ब्रुनेई',
         'बुल्गारिया',
-        'बुर्किना',
-        'फ़ासो',
+        'बुर्किना फ़ासो',
         'बर्मा',
         'बुरूंडी',
         'डोमिनिकन रिपब्लिक',
@@ -178,18 +163,15 @@ class Provider(AddressProvider):
         'गेबोन',
         'गाम्बिया',
         'जर्मनी',
-        'जार्जिया ग्रेनेडा',
+        'ग्रेनेडा',
         'घाना',
-        'यूनान',
         'ग्रेट ब्रिटेन',
         'हंगरी',
         'भारत',
+        'हिन्दुस्तान',
         'इराक',
         'आयरलैंड',
         'इंडोनेशिया',
-        'इसराइल',
-        'आइलैंड',
-        'ईरान',
         'इटली',
         'जमैका',
         'जॉर्डन',
@@ -201,7 +183,7 @@ class Provider(AddressProvider):
         'लातविया',
         'लाओस',
         'उत्तर कोरिया',
-        'दक्षिण कोसोवो',
+        'कोसोवो',
         'कुवैत',
         'लेबनान',
         'लिचटीनस्टीन',
@@ -211,15 +193,13 @@ class Provider(AddressProvider):
         'लाइबेरिया',
         'लेसोथो',
         'नेपाल',
-        'न्यूजीलैंड',
+        'न्यूज़ीलैण्ड',
         'निकारागुआ',
         'नाइजर',
         'नाउरू',
-        'लुसिया',
-        'रूस',
+        'सेंट लुसिया',
         'रोमानिया',
-        'अरब',
-        'अमीरात',
+        'अरब अमीरात',
         'यूएई',
         'युगांडा',
         'यूक्रेन',
@@ -233,8 +213,17 @@ class Provider(AddressProvider):
         'वियतनाम',
         'यमन',
         'ज़ायर',
-        'जाबम्बया',
-        'जिम्बाब्वे',
+        'ज़ाम्बिया',
+        'ज़िम्बाब्वे',
+        'पाकिस्तान',
+        'सउदी अरब',
+        'ओमान',
+        'क़तर',
+        'ट्यूनीशिया',
+        'मोरक्को',
+        'तुर्की',
+        'श्रीलंका',
+        'अफ़ग़ानिस्तान',
     )
 
     def city_name(self):
