@@ -1,6 +1,3 @@
-# coding=utf-8
-
-from __future__ import unicode_literals
 from .. import Provider as AutomotiveProvider
 
 
@@ -9,5 +6,5 @@ class Provider(AutomotiveProvider):
     # https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_the_United_Kingdom
     license_formats = (
         '??## ???',
-        '??##???'
+        '??##???',
     )
